# Debugger tool
[X](https://twitter.com/itsrishub) | [linkedin](https://www.linkedin.com/in/itsrishub)

Debug your code with advance python module, get time of execution, parameters, returns and many more.

Import:
```
from xladybug import debug
```

Usage for functions:
```
@debug
def function():
    #your_code
```

Usage for variables:
```
x = 10
debug(x)
```

Usage for debugging:
```
debug('here!')
```
